# Collaboration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/collaboration#overview)
  * [Collaboration Features in SAP LeanIX](https://help.sap.com/docs/leanix/ea/collaboration#collaboration-features-in-sap-leanix)
  * [Surveys](https://help.sap.com/docs/leanix/ea/collaboration#surveys)
  * [To-Dos](https://help.sap.com/docs/leanix/ea/collaboration#to-dos)
  * [Comments](https://help.sap.com/docs/leanix/ea/collaboration#comments)
  * [Subscription to Fact Sheets](https://help.sap.com/docs/leanix/ea/collaboration#subscription-to-fact-sheets)
  * [Quality Seals](https://help.sap.com/docs/leanix/ea/collaboration#quality-seals)


SAP LeanIX offers several robust collaboration features, such as surveys, to-dos, comments, fact sheet subscriptions, and comments, to make stakeholder participation easier in enriching and validating data, and thereby ensuring data quality and completeness.
